pilas.actores.bomba

Package pilas :: Package actores :: Module bomba |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.bomba

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10  from pilas.actores import Animacion
    11  from pilas.actores import Explosion
    12
    13
    14 -class Bomba(Animacion):
    15      """Representa una bomba que puede explotar...
    16
    17      .. image:: images/actores/bomba.png
    18
    19      La bomba adquiere la habilidad explotar al momento de crearse, así
    20      que puedes invocar a su método "explotar" y la bomba hará un
    21      explosión en pantalla con sonido.
    22
    23      Este es un ejemplo de uso del actor:
    24
    25          >>> bomba = pilas.actores.Bomba()
    26          >>> bomba.explotar()
    27      """
    28
    29 -    def __init__(self, x=0, y=0):
    30          """ Constructor de la Bomba.
    31
    32          :param x: Posición horizontal del Actor.
    33          :type x: int
    34          :param y: Posición vertical del Actor.
    35          :type y: int
    36          """
    37          grilla = pilas.imagenes.cargar_grilla("bomba.png", 2)
    38          Animacion.__init__(self, grilla, ciclica=True, x=x, y=y)
    39          self.radio_de_colision = 25
    40          self.aprender(pilas.habilidades.PuedeExplotar)
    41
    42 -    def explotar(self):
    43          """Hace explotar a la bomba y la elimina de la pantalla."""
    44          self.eliminar()
    45